
*Analysis-----Descriptive graphs and regression analysis

cls 

clear all

cap log close

log using analysis.log, text replace

*** Setting Global variable for ease of folder navigation
global data "$master\Data"
global temp "$data\temp"
global outputdata "$data\outputdata"
gl PALMS "$data\palms"
gl RESULTS "$master\output"

set more off

grstyle init
grstyle set imesh, horizontal compact minor
grstyle set symbol Oh T D S X O
grstyle linepattern major_grid dash
grstyle set graphsize 5cm 5cm
grstyle set color RdYlGn, n(5) opacity(50)
	
use "$PALMS/PALMS4_GTI_CLEAN.dta", clear

*------------------------------------------------------------------------------------------
*------------------------------------------------------------------------------------------

*1. PART 1: Descriptive Analysis (graphs)

*------------------------------------------------------------------------------------------
*Skill level>Figure 1
*------------------------------------------------------------------------------------------
			graph bar if green_strict==1  [pw=newweight], over(skill_level) stack asyvars ///
	percentage ytitle(Percent)   ///
	legend(position(below) col(3) bmargin(large)) ///
plotregion(color(white))  legend(col(4)) name(skillstrict,replace) ///
title(" Green strict ", span size(medium)) blabel(bar, pos(inside) size(small) format(%2.0f)) 
		
			graph bar if green_broad==1  [pw=newweight], over(skill_level) stack asyvars ///
	percentage ytitle( " ")   ///
	legend(position(below) col(3) bmargin(large)) ///
plotregion(color(white))  legend(col(4)) name(skillbroad,replace) ///
title(" Green broad ", span size(medium)) blabel(bar, pos(inside) size(small) format(%2.0f)) 
	
	        graph bar [pw=newweight], over(skill_level) stack asyvars ///
	percentage ytitle("")   ///
	legend(position(below) col(3) bmargin(large)) ///
plotregion(color(white))  legend(col(4)) name(skillall,replace) ///
title(" All employed ", span size(medium)) blabel(bar, pos(inside) size(small) format(%2.0f))

grc1leg skillstrict skillbroad skillall, graphregion(color(white))  col(3) name(skills, replace) ///
	title(" ")

	graph export "$RESULTS\figure 1 skills.png", replace


*------------------------------------------------------------------------------------------
*Figure 2: Green employment over time
*------------------------------------------------------------------------------------------
use "$PALMS/PALMS4_GTI_CLEAN.dta", clear
	
		collapse green_strict green_broad [pw=ceweight1], by(wave)
duplicates drop		
foreach X of varlist green_strict green_broad {
	gen `X'p=`X'*100
	}

	label define wave 39 "2012q1", modify
label define wave 40 "2012q2", modify
label define wave 41 "2012q3", modify
label define wave 42 "2012q4", modify
label define wave 43 "2013q1", modify
label define wave 44 "2013q2", modify
label define wave 45 "2013q3", modify
label define wave 46 "2013q4", modify
label define wave 47 "2014q1", modify
label define wave 48 "2014q2", modify
label define wave 49 "2014q3", modify
label define wave 50 "2014q4", modify
label define wave 51 "2015q1", modify
label define wave 52 "2015q2", modify
label define wave 53 "2015q3", modify
label define wave 54 "2015q4", modify
label define wave 55 "2016q1", modify
label define wave 56 "2016q2", modify
label define wave 57 "2016q3", modify
label define wave 58 "2016q4", modify
label define wave 59 "2017q1", modify
label define wave 60 "2017q2", modify
label define wave 61 "2017q3", modify
label define wave 62 "2017q4", modify
label define wave 63 "2018q1", modify
label define wave 64 "2018q2", modify
label define wave 65 "2018q3", modify
label define wave 66 "2018q4", modify
label define wave 67 "2019q1", modify
label define wave 68 "2019q2", modify
label define wave 69 "2019q3", modify
label define wave 70 "2019q4", modify

label values wave wave
 
graph twoway (line green_strictp wave , yaxis(1) yscale(axis(1)) ///
legend(label(1 "Green strict") cols(5) size(small)) clcolor(black) clwidth(medthick) clpattern(dash)) ///
(line green_broadp wave ,yaxis(2) yscale(axis(2))  ///
legend(label(2 "Green broad") cols(5) size(small)) clcolor(eltblue) clwidth(medthick) clpattern(solid)), ///
xlab(39(1)70, valuelabel angle(45) grid )  ///
ylab(3(.5)6, grid) xtitle("Year") ytitle("Share green strict (%)") ytitle("Share green broad (%)", axis(2)) ///
 legend(position(5) col(5) bmargin(medium))    ///
title(" ") scheme(plottig) name(greentrend,replace) 

	 graph export "$RESULTS\figure 2 trend.png", replace

	
*---------------------------------------------------------------------------------------
	*Figure 3 gender
*---------------------------------------------------------------------------------------

use "$PALMS/PALMS4_GTI_CLEAN.dta", clear
	
	graph bar if green_strict==1 [pw=newweight], over(female)  stack asyvars ///
	percentage ytitle(Green employment by gender)   ///
	legend(position(below) col(2) bmargin(large)) ///
plotregion(color(white))  legend(col(5)) name(strict,replace) ///
title(" Green strict", span size(medium)) blabel(bar, pos(center) size(medium) format(%2.0f))

	graph bar if green_broad==1 [pw=newweight], over(female)  stack asyvars ///
	percentage ytitle(" ")   ///
	legend(position(below) col(2) bmargin(large)) ///
plotregion(color(white))  legend(col(5)) name(broad,replace) ///
title(" Green broad", span size(medium)) blabel(bar, pos(center) size(medium) format(%2.0f))

	graph bar [pw=newweight], over(female)  stack asyvars ///
	percentage ytitle(" ")   ///
	legend(position(below) col(2) bmargin(large)) ///
plotregion(color(white))  legend(col(5)) name(all,replace) ///
title(" All employed", span size(medium)) blabel(bar, pos(center) size(medium) format(%2.0f))

grc1leg strict broad all, graphregion(color(white)) col(3) name(gender, replace) ///
	title(" ")

	 graph export "$RESULTS\figure 3 gender.png", replace
*---------------------------------------------------------------------------------------
	*Figure 4 Race
*---------------------------------------------------------------------------------------			
			graph bar if green_strict==1  [pw=newweight], over(race) stack asyvars ///
	percentage ytitle(Percent)   ///
	legend(position(below) col(2) bmargin(large)) ///
plotregion(color(white))  legend(col(4)) name(racestrict,replace) ///
title(" Green strict ", span size(medium)) blabel(bar, pos(center) size(small) format(%2.0f)) 
		
			graph bar if green_broad==1  [pw=newweight], over(race) stack asyvars ///
	percentage ytitle( " ")   ///
	legend(position(below) col(2) bmargin(large)) ///
plotregion(color(white))  legend(col(4)) name(racebroad,replace) ///
title(" Green broad ", span size(medium)) blabel(bar, pos(center) size(small) format(%2.0f)) 
	
				graph bar [pw=newweight], over(race) stack asyvars ///
	percentage ytitle( " ")   ///
	legend(position(below) col(2) bmargin(large)) ///
plotregion(color(white))  legend(col(4)) name(all,replace) ///
title(" All employed ", span size(medium)) blabel(bar, pos(center) size(small) format(%2.0f)) 

	grc1leg racestrict racebroad all , graphregion(color(white)) col(3) name(race, replace) ///
	title("")
	
		 graph export "$RESULTS\Figure 4 race.png", replace

*------------------------------------------------------------------------------------------
*Figure 5 Age category
*------------------------------------------------------------------------------------------
				graph bar if green_strict==1  [pw=newweight], over(agecat) stack asyvars ///
	percentage ytitle(Percent)   ///
	legend(position(below) col(2) bmargin(large)) ///
plotregion(color(white)) legend(col(5)) name(strict,replace) ///
title(" Green strict", span size(medium)) blabel(bar, pos(inside) size(small) format(%2.0f)) 

				graph bar if green_broad==1  [pw=newweight], over(agecat) stack asyvars ///
	percentage ytitle("")   ///
	legend(position(below) col(2) bmargin(large)) ///
plotregion(color(white)) legend(col(5)) name(broad,replace) ///
title(" Green broad", span size(medium)) blabel(bar, pos(inside) size(small) format(%2.0f)) 

				graph bar [pw=newweight], over(agecat) stack asyvars ///
	percentage ytitle("")   ///
	legend(position(below) col(2) bmargin(large)) ///
plotregion(color(white)) legend(col(5)) name(all,replace) ///
title(" All employed", span size(medium)) blabel(bar, pos(inside) size(small) format(%2.0f)) 

grc1leg strict broad all, graphregion(color(white)) col(3) name(agecat, replace) ///
	title(" ")

graph export "$RESULTS/Figure 5 agecat.png", replace

*------------------------------------------------------------------------------------------
*Figure 6 Education
*------------------------------------------------------------------------------------------
				graph bar if green_strict==1  [pw=newweight], over(educ_NQF) stack asyvars ///
	percentage ytitle(Percent)   ///
	legend(position(below) col(2) bmargin(large)) ///
plotregion(color(white)) legend(col(5)) name(educstrict,replace) ///
title(" Green strict", span size(medium)) blabel(bar, pos(inside) size(small) format(%2.0f)) 

				graph bar if green_broad==1  [pw=newweight], over(educ_NQF) stack asyvars ///
	percentage ytitle("")   ///
	legend(position(below) col(2) bmargin(large)) ///
plotregion(color(white)) legend(col(5)) name(educbroad,replace) ///
title(" Green broad", span size(medium)) blabel(bar, pos(inside) size(small) format(%2.0f)) 

				graph bar [pw=newweight], over(educ_NQF) stack asyvars ///
	percentage ytitle("")   ///
	legend(position(below) col(2) bmargin(large)) ///
plotregion(color(white)) legend(col(5)) name(educall,replace) ///
title(" All employed", span size(medium)) blabel(bar, pos(inside) size(small) format(%2.0f)) 

grc1leg educstrict educbroad educall, graphregion(color(white)) col(3) name(educ, replace) ///
	title(" ")

graph export "$RESULTS/Figure 6 educ.png", replace

*------------------------------------------------------------------------------------------
*Figure 7: Sector of employment
*------------------------------------------------------------------------------------------

		graph bar if green_strict==1 [pw=newweight], over(Indus1) stack asyvars ///
	percentage ytitle(Distribution of employment by main industry)   ///
	legend(position(below) col(2) bmargin(large)) ///
plotregion(color(white))  legend(col(5)) name(strict,replace) ///
title(" Green strict", span size(medium)) blabel(bar, pos(center) size(small) format(%2.0f))

	graph bar if green_broad==1 [pw=newweight], over(Indus1) stack asyvars ///
	percentage ytitle(" ")   ///
	legend(position(below) col(2) bmargin(large)) ///
plotregion(color(white))  legend(col(5)) name(broad,replace) ///
title("Green broad ", span size(medium)) blabel(bar, pos(center) size(small) format(%2.0f))

	graph bar [pw=newweight], over(Indus1) stack asyvars ///
	percentage ytitle(" ")   ///
	legend(position(below) col(2) bmargin(large)) ///
plotregion(color(white))  legend(col(5)) name(all,replace) ///
title("All employed", span size(medium)) blabel(bar, pos(center) size(small) format(%2.0f))

grc1leg strict broad all, graphregion(color(white)) col(3) name(sector, replace) ///
	title(" ")

	graph export "$RESULTS/Figure 7 industry.png", replace
	

*------------------------------------------------------------------------------------------
*------------------------------------------------------------------------------------------

*2. Part 2: Regression Analysis
*------------------------------------------------------------------------------------------
*Table 4: PROBABILITY OF BEING IN A GREEN JOB

use "$PALMS/PALMS4_GTI_CLEAN.dta", clear

*NO INDUSTRY
*------------------------------------------------------------------------------------------

logit green_strict female i.agecat gr12 cert dip_degree Coloured Indian White urban ec nc fs kzn nw gt mpl limp i.wave [pw=newweight32]

margins if e(sample) , dydx(*) post
outreg2 using "$RESULTS\Logit-Table 4.xls", excel ct("Strict")  dec(3) replace

logit green_strict female i.agecat gr12 cert dip_degree Coloured Indian White urban ec nc fs kzn nw gt mpl limp i.wave Indus_agric Indus_mining Indus_manuf Indus_utilit Indus_const Indus_trade Indus_trans Indus_finance [pw=newweight32]

margins if e(sample) , dydx(*) post
outreg2 using "$RESULTS\Logit-Table 4.xls", excel ct("Strict-Indus")  dec(3) append

*------------------------------------------------------------------------------------------
//BROADLY GREEN
*------------------------------------------------------------------------------------------


logit green_broad female i.agecat gr12 cert dip_degree Coloured Indian White urban ec nc fs kzn nw gt mpl limp i.wave [pw=newweight32]

margins if e(sample) , dydx(*) post
outreg2 using "$RESULTS\Logit-Table 4.xls", excel ct("Broad")  dec(3) append

logit green_broad female i.agecat gr12 cert dip_degree Coloured Indian White urban ec nc fs kzn nw gt mpl limp i.wave Indus_agric Indus_mining Indus_manuf Indus_utilit Indus_const Indus_trade Indus_trans Indus_finance [pw=newweight32]

margins if e(sample) , dydx(*) post
outreg2 using "$RESULTS\Logit-Table 4.xls", excel ct("Broad-Indus")  dec(3) append

//
*------------------------------------------------------------------------------------------
*Table 5: OLS regression (logGTI)
*------------------------------------------------------------------------------------------

*Characteristics associated with being in a green jobs
use "$PALMS/PALMS4_GTI_CLEAN.dta", clear

keep if green_strict==1

gen logGTI=log(GTI_Narrow)

reg logGTI female i.agecat gr12 cert dip_degree Coloured Indian White urban ec nc fs kzn nw gt mpl limp i.wave [pw=newweight32]

outreg2 using "$RESULTS\Table 5 OLS-GTI.xls", excel ct("NO INDUST")  dec(3) replace

reg logGTI female i.agecat gr12 cert dip_degree Coloured Indian White urban ec nc fs kzn nw gt mpl limp i.wave Indus_agric Indus_mining Indus_manuf Indus_utilit Indus_const Indus_trade Indus_trans Indus_finance  [pw=newweight32]

outreg2 using "$RESULTS\Table 5 OLS-GTI.xls", excel ct("FULL ")  dec(3) append

*------------------------------------------------------------------------------------------
*Table 6: OLS regression (logwage)
*------------------------------------------------------------------------------------------

use "$PALMS/PALMS4_GTI_CLEAN.dta", clear

reg logw green_strict urban ec nc fs kzn nw gt mpl limp i.wave   [pw=bracketweight24]

outreg2 using "$RESULTS\Table 6 Log wage.xls", excel ct("Strict-Baseline")  dec(3) replace


reg logw green_strict female age age2 gr12 cert dip_degree Coloured Indian White Indus_agric Indus_mining Indus_manuf Indus_utilit Indus_const Indus_trade Indus_trans Indus_finance urban ec nc fs kzn nw gt mpl limp i.wave occ_managers occ_profess occ_tech occ_clerks occ_services occ_craft occ_operators occ_elemen  [pw=bracketweight24]

outreg2 using "$RESULTS\Table 6 Log wage.xls", excel ct("Strict-FULL")  dec(3) append

*------------------------------------------------------------------------------------------
//BROADLY GREEN
*------------------------------------------------------------------------------------------

reg logw green_broad urban ec nc fs kzn nw gt mpl limp i.wave   [pw=bracketweight24]

outreg2 using "$RESULTS\Table 6 Log wage.xls", excel ct("Broad-Baseline")  dec(3) append

reg logw green_broad female age age2 gr12 cert dip_degree Coloured Indian White Indus_agric Indus_mining Indus_manuf Indus_utilit Indus_const Indus_trade Indus_trans Indus_finance urban ec nc fs kzn nw gt mpl limp i.wave occ_managers occ_profess occ_tech occ_clerks occ_services occ_craft occ_operators occ_elemen  [pw=bracketweight24]

outreg2 using "$RESULTS\Table 6 Log wage.xls", excel ct("Broad-Full")  dec(3) append

//
*------------------------------------------------------------------------------------------

log close

exit

