* Creating the final dataset----PALMS4_GTI_ONET_Aug

cls 

clear all

cap log close

log using master.log, text replace

*** Setting Global variable for ease of folder navigation
global data "$master\Data"
global temp "$data\temp"
global outputdata "$data\outputdata"
gl PALMS "$data\palms"
gl RESULTS "$master\output"

set more off


use "$PALMS\palms4waves.dta", clear
keep if empstat1 == 1
keep if occupation2 > 1000
drop if occupation2 == 9999

 sort occupation2
 
 merge m:1 occupation2 using "$outputdata/greenOCCS_isco88.dta"
 /*
. tab _merge

                 _merge |      Freq.     Percent        Cum.
------------------------+-----------------------------------
         using only (2) |          9        0.00        0.00
            matched (3) |    616,178      100.00      100.00
------------------------+-----------------------------------
                  Total |    616,187      100.00

. tab occupation2 if _merge==2

    4 digit occ code LFS 2002:2 onwards |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
General managers not elsewhere classifi |          1       11.11       11.11
Health professionals (except nursing) n |          1       11.11       22.22
Other teaching professionals not elsewh |          1       11.11       33.33
           Computer equipment operators |          1       11.11       44.44
                  Companions and valets |          1       11.11       55.56
        Astrologers and related workers |          1       11.11       66.67
                 Mixed-animal producers |          1       11.11       77.78
         Stereotypers and electrotypers |          1       11.11       88.89
Tobacco preparers and tobacco products  |          1       11.11      100.00
----------------------------------------+-----------------------------------
                                  Total |          9      100.00

*/
 
 drop if _merge==2
 
  drop _merge
**------------------------------------------------------------------------------
* CHANGING PERSONAL AND PROTECTIVE SERVICES FROM GREEN STRICT TO POTENTIAL GREEN
*-------------------------------------------------------------------------------
 
   replace GTI_Narrow=0 if occupation2==5169              //PERSONAL AND PROTECTIVE SERVICES
   
/*Our original list had 47 strictly green occupations, including ISCO code 5169 (protective services not elsewhere classified) with a GTI of 10 percent. We chose to shift this occupation to the list of broadly defined green occupations. While this occupation contains jobs such as park rangers and wardens, that would be classified as green (park rangers are classified as green in the DHET (2013) OFO skills list), the majority of the workers in this occupation are security officers whose tasks cannot be classified as strictly green. In the end, because this occupation accounts for a very large share of jobs (over 500,000 employees), removing this occupation from the strictly green occupations list reduced the share of strictly green employment in South Africa from 9 percent to 5.5 percent*/
   
		cap drop green_cat
		cap drop green
		gen green_cat=0 if employed==1
replace green_cat=2 if (GTI_Narrow>0) & GTI_Narrow!=.
replace green_cat=1 if (GTI_Broad>0 & green_cat!=2) 
replace green_cat=. if GTI_Broad==. 

		label def green_cat 1 "Green Potential" 2 "Green" 0 "Zero green", replace
	label val green_cat green_cat

*-------------------------------------------------------------------------------
*Green Strict
*-------------------------------------------------------------------------------
		cap drop green_strict
		gen green_strict=0 if employed==1
replace green_strict=1 if (GTI_Narrow>0 & GTI_Narrow!=.)

		label def green_strict  1 "Green_Narrow" 0 "Non-green", replace
	label val green_strict green_strict

*-------------------------------------------------------------------------------------
*Green broad
*-------------------------------------------------------------------------------------
cap drop green_broad
		gen green_broad=0 if employed==1
replace green_broad=1 if (GTI_Broad>0 & GTI_Broad!=.)

		label def green_broad  1 "GreenGTI Broad" 0 "Non-green", replace
	label val green_broad green_broad 
	
*-------------------------------------------------------------------------------------
*weights
*-------------------------------------------------------------------------------------
	
egen occtot = sum(employed), by(occupation2)
egen Totalempl=sum(employed)
gen occshare=occtot/Totalempl*100

*-------------------------------------------------------------------------------------
*skill_level
*-------------------------------------------------------------------------------------

gen skill_level=. & occup!=.
replace skill_level=3 if occup==1|occup==2|occup==3 & occup!=.
replace skill_level=2 if occup>3 & occup<9 & occup!=.
replace skill_level=1 if occup>=9 & occup!=.

		label def skill_level  3 "High-level" 2 "Mid-level" 1 "Elementary", replace
	label val skill_level  skill_level
		label var skill_level  "SASCO skill category"

tab skill_level, gen(skill)
ren skill1 Elementary
ren skill2 Mid_level
ren skill3 High_level

*------------------------------------------------------------------------------------------
*Informal Sector
*------------------------------------------------------------------------------------------

gen Informal=0 if empstat1==1 & informal_emp_derived!=.
replace Informal=0 if empstat1==1 & Infempl!=.
replace Informal=1 if informal_emp_derived==2 & public!=1
replace Informal=1 if Infempl==2 & public!=1

lab define Informal 0 "No" 1 "Yes"  
lab val Informal Informal

save "$PALMS/PALMS4_GTI_CLEAN.dta", replace


exit