*Jacqueline Mosomi
*This code is adapted from Granata and Posadas
* Methodology created by Julia Granata and Josefina Posadas 

clear all
global data "$master\Data\GTI"
global temp "$master\Data\temp"
global tasks "$master\Data\GTI\tasks"


* 1. Create occupational database with task statements
	
	import excel using "$data\ISCOGroups_en.xlsx", clear first
	keep if code>999 & code!=. // keep only the one that re in our analysis
	replace description = lower(description)
	split description, parse("include -" "(a)" "(b)" "(c)" "(d)" "(e)" "(f)" "(g)" "(h)" "(i)" "(j)" "(k)" "(l)" "(m)" "(n)" "(o)" "(p)" "(q)" "(r)" "(s)" "(t)" "(u)" "(v)" "(w)" "(x)" "(y)" "(z)" "examples of the occupations classified here:")
	drop description description1 description2
	local num=3
	foreach i in a b c d e f g h i j k l m n o{
		ren description`num' task_`i'
		replace task_`i'="" if regexm(task_`i', "-  ")
		local ++num
	}
	reshape long task_ , i(conceptType conceptUri code preferredLabel altLabels inScheme) j(taskcode) string
	drop if task_=="" & taskcode!="a"
	drop if regexm(task_, "- ")

	compress
	save "$temp\U_ISCOdata.dta", replace

	* 2. Import green dictionary
	
	* Green dictionary specifications // ---> change if dictionary is modified 
	local dict "Dictionary of green terms 11 11 21 SA.xlsx"
	local dict_out "DICT_11nov2021.dta"
	local maximus "E455"  
	
	import excel using "$data/`dict'", clear cellrange(A4:`maximus') first
	drop if Type=="Remove"
	tempfile dictionary
	save `dictionary', replace

	gen Termsroot_x = lower(Termsroot)
	gen Exceptions_x = lower(Exceptions)
	split Exceptions_x, parse(", ")
	drop Exceptions_x

	compress
	saveold "$temp/`dict_out'", replace

	* Identify present green terms in task database 
	use "$temp/`dict_out'", clear
	gen Termsroot_y=Termsroot_x + "|" + Skillscategory
	levelsof Termsroot_y, local(terminology)
	return list

	* Exceptions
	forval z = 1/20{  // --> the current dictionary has up to 20 exceptions in place, modify if needed
		cap levelsof Exceptions_x`z', local(exc`z')
		if _rc!=0{
			di "No variable Exceptions_x`z': Skipped"
			}
	}

* 3. Classify task statements into green,green potential, and non-green

	use "$temp\U_ISCOdata.dta", clear
	forval i=1/20{   // Tasks statements have up to 8 green terms - allowing to have up to 20 as matchword, but modify as needed
		gen cat_`i'=""
		gen matchword`i'=""
	}
	gen green_skill=0
	foreach i in `terminology'{
	local pos = strpos("`i'", "|") + 1
	local j = substr("`i'", `pos', .)
	local posx = strpos("`i'", "|") - 1
	local k = substr("`i'", 1, `posx')
	*local k = " " + "`k'" + " " // not necessary blankspace
	
	di ""
	di "`i'"
	di "`k'"
	di "`j'"
	
	replace green_skill=green_skill + 1 if regexm(task_, "`k'")
	
	forval x=1/20{
		replace cat_`x' = "`j'" if green_skill==`x' & cat_`x'==""
		replace matchword`x' = "`k'" if green_skill==`x' & matchword`x'==""
		}
	}
	order green_skill, after(task_)
	reshape long cat_ matchword, i(conceptType conceptUri code preferredLabel altLabels inScheme taskcode task_ green_skill) j(skoda) string

	drop skoda
	duplicates drop *, force
	drop if cat_=="" & green_skill!=0
	sort code taskcode green_skill cat_
	
	* get only first letter of skillscategory
	replace cat_=upper(cat_)
	split cat_, parse(" ") gen(words)

	ds words*
	local cnt=1
	gen startingletters=""

	foreach i in `r(varlist)'{
		replace startingletters = startingletters + substr(words`cnt', 1, 1)
		local ++cnt
	}
	
	replace startingletters=subinstr(startingletters, "&", "", .)
	
	drop cat_ words*
	replace startingletters="NonGreen" if startingletters==""
	recast str2045 task_, force

	ren green_skill total_terms_matched
	gen green_skill=0
	replace green_skill=1 if total_terms_matched!=0 & total_terms_matched!=.

	*Drop if matchword is an exemption
	gen ttotal_terms_matched=total_terms_matched
	gen t=""
	gen t2=0
	forval x=1/20{
		foreach i in `exc`x''{
			foreach m in total_terms_matched {
				replace t="`i'" if regexm(task_, "`i'")
				replace t2=1 if regexm("`i'", matchword)
				replace `m' = 0 if t!="" & t2==1 
			}
		replace matchword = "" if t!="" & t2==1 
		replace startingletters = "NonGreen" if t!="" & t2==1 
		replace green_skill = 0 if t!="" & t2==1 
		}
	}
	bysort code taskcode: gen t3=_n
	bysort code taskcode: egen t4=max(t3)
	drop if t4!=1 & total_terms_matched==0
	drop ttotal_terms_matched t t2 t3 t4 conceptUri conceptType altLabels inScheme
	
	duplicates drop   code preferredLabel  taskcode task_ total_terms_matched matchword startingletters, force
	rename matchword Termsroot 
	merge m:1 Termsroot using `dictionary'
	drop if _merge==2
	drop _merge
	gen g=0
	replace g=1 if Type=="Green"
 
	rename  Termsroot  matchword
	reshape wide green_skill, i(code preferredLabel  taskcode task_ matchword total_terms_matched) j(startingletters) string 
	
	drop green_skillNonGreen
	gen green_skill=0
	replace green_skill=1 if total_terms_matched!=0 & total_terms_matched!=.

	ren green_skill GreenSkill

	ds green_skill*
	foreach i in `r(varlist)'{
		replace `i'=0 if `i'==.
	}
	
	* minor fix in data
	drop if total_terms_matched!=0 & matchword==""
	bys code taskcode task_ GreenSkill total_terms_matched: gen order=_n

	* Currently, there are 8 maximum mathcwords ---> modify as needed
	forval i=1/7{
		bys code taskcode task_ GreenSkill total_terms_matched: replace matchword = matchword + "," + matchword[_n+`i'] if order==1
	}

	replace matchword=subinstr(matchword, ",", "|", .) // no spacing now
	replace matchword=subinstr(matchword, "||||||", "", .)
	replace matchword=subinstr(matchword, "|||||", "", .)
	replace matchword=subinstr(matchword, "||||", "", .)
	replace matchword=subinstr(matchword, "|||", "", .)
	replace matchword=subinstr(matchword, "||", "", .)

	replace matchword="" if order!=1

	forval i=1/7{
		bys code taskcode task_ GreenSkill total_terms_matched: replace matchword = matchword[_n-`i'] if matchword==""
	}

	collapse (max) GreenSkill total_terms_matched (mean) g   (sum) green_skill*, by(code preferredLabel taskcode task_ matchword)

	* Create green type categorization
	rename g confidence
	label var confidence "Share green vs. potentially green"
	order code preferredLabel taskcode task_ GreenSkill confidence total_terms_matched green_skill* matchword
	gsort code taskcode 
	label var green_skillAFAFP "Agriculture, forestry, and fish production"
	label var green_skillCE "Clean energy"
	label var green_skillCT "Other common terms"
	label var green_skillEE "Energy efficiency"
	label var green_skillEK "Environmental knowledge"
	label var green_skillERAC "Environmental regulations and compliance"
	label var green_skillGGRPRR "GHG reduction and pollution reduction & removal"
	label var green_skillLM "Low-carbon mobility"
	label var green_skillNRC "Natural Resource Conservation"
	label var green_skillRAROWAM "Recycling and reuse of waste and materials"
	label var green_skillR "Repair"
	
	global green_varlist green_skillAFAFP green_skillCE green_skillCT green_skillEE green_skillEK green_skillERAC green_skillGGRPRR  green_skillLM green_skillNRC green_skillRAROWAM green_skillR

	* Replace by share of task that it is in each category - categories are weighted according to number of terms
	foreach var in $green_varlist {
		replace `var'=`var'/total_terms_matched
		replace `var'=0 if `var'==.
	}
	* Total categories and replacements
	gen total_cat=0
	foreach type in $green_varlist {
		replace total_cat=total_cat+1 if `type'>0
	}
	gen GS_type=. 
	local l=1
	foreach type in $green_varlist {
		replace GS_type=`l' if `type'>0
		local l=`l'+1
	}

	replace GS_type=15 if total_cat>1

	label def g_cat 1 "Agriculture, forestry, and fish production" 2 "Clean energy" 3 "Climate change terms" 4 "Energy efficiency" 5 "Environmental knowledge" 6  "Environmental regulations and compliance" 7 "GHG reduction and pollution reduction & removal" 8 "Low-carbon mobility" 9 "Natural Resource Conservation" 10 "Recycling and reuse of waste and materials" 11 "Repair" 15 "Multiple", replace
	label val GS_type g_cat
	label var GS_type "Green category"

	* Repair is considered green potential: (RP)
	gen Green=0
	replace Green=2 if confidence>0
	replace Green=1 if GreenSkill==1 & Green==0
	label def conf 2 "Green" 1 "Green potential" 0 "Non-green", replace
	label val Green conf
	label var Green "Green confidence (repair is g potential)"

	rename GreenSkill GTBroad
	gen GTNarrow=0
	replace GTNarrow=1 if Green==2
	label var GTBroad "Green task (broad)" 
	label var GTNarrow "Green task (narrow)" 

	order  GTBroad GTNarrow  confidence  GS_type , after(Green)
	order  total_*, last

	compress
	saveold "$temp\ISCO_GREENTASKS.dta", replace
	global ISCO_GT "$temp\ISCO_GREENTASKS.dta"

* 4. List of all task statements categorized into green, potentially green and non-green
	
	use "$ISCO_GT" , clear	
	keep code preferredLabel taskcode task_ Green GS_type
	order code preferredLabel taskcode task_ Green GS_type, first
	gsort code -Green taskcode
	label var code "ISCO-08"
	label var preferredLabel "Occupational title"
	label var taskcode "Task ID"
	label var task_ "Task statement"
	label var Green "Green?"
	label var GS_type "Green category"

	putexcel set  "$tasks\Green occupations.xlsx", modify  sheet("Tasks")
	putexcel A1=("0. Lists of occupational tasks statements") 			
	export excel using "$tasks\Green occupations.xlsx",  sheetmodify  sheet("Tasks") firstrow(varlabels) cell(A3) keepcellfmt 
	
* 5. Occupational Green Task Intensity (GTI)
	
	use "$ISCO_GT" , clear
	gen task_count=1
		
	collapse (count) task_count (sum) GTBroad GTNarrow  , by(code preferredLabel)
	label var task_count "Total tasks"
			
	* Create GTI
	gen GTI_Broad=GTBroad/task_count*100
	gen GTI_Narrow=GTNarrow/task_count*100	
	label var GTI_Broad "GTI Broad"
	label var GTI_Narrow "GTI Narrow"

	gsort -GTI_Broad -GTI_Narrow  code
	gen rank_Broad=_n
	gsort -GTI_Narrow -GTI_Broad code
	gen rank_Narrow=_n

	order code preferredLabel rank_Narrow GTI_Narrow rank_Broad GTI_Broad task_count GTNarrow GTBroad
	label var code "ISCO-08"
	label var preferredLabel "Occupational title"
	label var rank_Narrow "Rank (Narrow)" 
	label var GTI_Narrow "GTI (Narrow)"
	label var rank_Broad "Rank (Broad)"
	label var GTI_Broad "GTI (Broad)"
	label var task_count "Total tasks"
	label var GTBroad "Total green tasks (Broad)"
	label var GTNarrow "Total green tasks (Narrow)"
	gsort -GTI_Narrow - GTI_Broad -code
	putexcel set  "$tasks\Green occupations.xlsx", modify  sheet("GTI")
	putexcel A1=("Occupational GTI") 			
	export excel using "$tasks\Green occupations.xlsx",  sheetmodify  sheet("GTI") firstrow(varlabels) cell(A3) keepcellfmt 

*****************************************
* Erase temporary files/directories
erase "$temp/U_ISCOdata.dta"
*erase "$temp/`dict_out'"
erase "$temp/ISCO_GREENTASKS.dta"
*rmdir "$temp"

save  "$tasks\greentasksSA.dta", replace

clear

exit
