*===============================================================================
* Jacqueline Mosomi
* Profiling green jobs in South Africa
* 
* APRIL 2024
* 
*STATA 17
*===============================================================================
clear all
*Before you execute the dofile

*1. IMPORTANT: grc1leg

*download and install grc1leg. 
*grc1leg combines graphs into one graph with a common legend.
* In stata search grc1leg to get a direct link to install
/*INSTALLATION FILES                                  
      grc1leg/grc1leg.ado             (click here to install)
      grc1leg/grc1leg.hlp  */

 *2. IMPORTANT: set scheme plotplainblind
 *before you execute the command ...set scheme plotplainblind..
*search plotplainblind in Stata
*Click on gr0070 to get the installation link
/*SJ-17-3 gr0070  . . . . . New graphic schemes for Stata: plotplain and plottig
        . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . D. Bischof
        (help scheme_plotplainblind, scheme_plotplain, scheme_plottigblind,
        scheme_plottig if installed)
        Q3/17   SJ 17(3):748--759
        presents two new graphic schemes, plotplain and plottig*/
/*
INSTALLATION FILES                                  (click here to install)
      gr0070/scheme-plotplainblind.scheme
      gr0070/scheme_plotplainblind.sthlp
      gr0070/scheme-plotplain.scheme
      gr0070/scheme_plotplain.sthlp
      gr0070/scheme-plottigblind.scheme
      gr0070/scheme_plottigblind.sthlp
      gr0070/scheme-plottig.scheme
      gr0070/scheme_plottig.sthlp
*/
/*		
* Make sure the following ado files are installed in Stata
capture ssc install dups
capture ssc install grstyle, replace
capture ssc install palettes
capture ssc install outreg2
capture ssc install colrspace
*/
*User's filepaths

*change the file paths to your computer's file paths

cd "C:/WBG\/Rep-checks/RR_ZAF_2024_124"

global master "."  //directory

gl dofiles "${master}/dofiles1"
global data "${master}/Data"
global temp "${master}/temp"
global outputdata "${master}/Data/outputdata"
gl PALMS "${master}/Data/palms"
gl RESULTS "${master}/output"
sysdir set PLUS "${dofiles}/ado"
mata: mata mlib index
set scheme plotplainblind
set varabbrev on

*-------------------------------------------------------------------------------
*1. Create GTI scores
*===============================================================================
*Creating the green task intensity (GTI) variables for South Africa.

*This data is not publicly available but can be obtained from the authors Granata and Posadas (2024). Why Look at Tasks When Designing Skills Policy for the Green Transition? A Methodological Note on How to Identify Green Occupations and the Skills They Require (English). Policy Research working paper; no. WPS 10753; PEOPLE Washington, D.C.: World Bank Group. http://documents.worldbank.org/curated/en/099507304172419760/IDU16ad6160713dd714cb81ba4f109325371b13. 

*Dofile adapted from Granata, J. and Posadas, J.  (2024). 

do "$dofiles/greentasksSA.do"													
*-------------------------------------------------------------------------------

*-------------------------------------------------------------------------------
*2. Crosswalk the scores from ISCO08-to ISCO88
*===============================================================================

*Final GTI variables using ISCO88 codes
*Crosswalks from ISCO-08 to ISCO88-----Note the GTI was created using ISCO08 occupation codes but PALMS occupation variable is coded using ISCO88 CODES
*We use an ILO crosswalk to move from ISCO08 to ISCO88. THE FILE IS PROVIDED IN EXCEL and stata format 

do "$dofiles/greenOCCS_isco88.do"													
*-------------------------------------------------------------------------------

*-------------------------------------------------------------------------------
*3. Cleaning PALMS 2012-2019
*===============================================================================

* Merging the RAW DATA==PALMS V3.3 to  QLFS 2019 Q3 and Q4. The data created is PALMS_q3q4qlfs2019

do "$dofiles/mergeqlfs_palms.do"

*-------------------------------------------------------------------------------

*4. PALMS variable creation and cleaning

do "$dofiles/palms4waves.do"			

*-------------------------------------------------------------------------------
*5. MERGING PALMS TO THE GREEN TASKS INTENSITY
*===============================================================================
do "$dofiles/PALMS4_GTI_CLEAN.do"													
*-------------------------------------------------------------------------------

*-------------------------------------------------------------------------------
*6. Appendix Tables containing all green occupations 
*===============================================================================
do "$dofiles/occupationcounts_1.do"
*-------------------------------------------------------------------------------

*-------------------------------------------------------------------------------
*6. Descriptive and Regression analysis
*===============================================================================
do "$dofiles/Analysis.do"

*-------------------------------------------------------------------------------
*===============================================================================
