*-------------------------------------------------------------------------------------*
* Cleaning palms  dataset
*-------------------------------------------------------------------------------------*	
cls 

clear all

cap log close

log using cleaningpalms.log, text replace

*** Setting Global variable for ease of folder navigation
global data "$master\Data"
global temp "$data\temp"
gl PALMS "$data\palms"
gl RESULTS "$master\output"

set more off

*download qlfs and palmsv3.3 from DataFirst website......//https://www.datafirst.uct.ac.za/dataportal/index.php/catalog/795/get-microdata

*-------------------------------------------------------------------------------
use "$PALMS\qlfs-2019-q3-worker-1.0-stata11.dta", clear
*-------------------------------------------------------------------------------

destring UQNO, replace
ren UQNO uqnr 
ren PERSONNO personnr

gen wave=69

tempfile qlfs2019_3
save `qlfs2019_3'

*-------------------------------------------------------------------------------
use "$PALMS\qlfs-2019-q4-worker-1.0-stata11.dta", clear
*-------------------------------------------------------------------------------

destring UQNO, replace
ren UQNO uqnr 
ren PERSONNO personnr

gen wave=70

tempfile qlfs2019_4
save `qlfs2019_4'

*-------------------------------------------------------------------------------
use `qlfs2019_3', clear
append using `qlfs2019_4', force

label define wave1 69 "QLFS 2019:3" 70 "QLFS 2019:4" , replace 

lab values wave wave1
gen year=.
replace year=2019 if year==. & wave==69
replace year=2019 if year==. & wave==70

tempfile qlfsq3q42019
save `qlfsq3q42019', replace

*-------------------------------------------------------------------------------
* renaming some variables
*-------------------------------------------------------------------------------
use `qlfsq3q42019', clear

rename Q14AGE age
rename Q13GENDER gender
rename Q15POPULATION race
ren 	Q42OCCUPATION occupation  //Occupation, 4 digit code
ren 	Q43INDUSTRY industry      //Industry,3digitcode in OHS 96-98 +QLFS
rename  Q17EDUCATION educhigh4  
rename  Province province
rename  Weight ceweight1 // NOT calibrated weight, rename such that it will merge
		
*------------------------------------------------------------------------
						*PUBLIC SECTOR 
*------------------------------------------------------------------------

  	gen public=.
	replace public=0 if Q415TYPEBUSNS==3| Q415TYPEBUSNS==4 | Q415TYPEBUSNS==5
	replace public=1 if Q415TYPEBUSNS==1| Q415TYPEBUSNS==2

*----------------------------------------------------------------------	
						*employment
*----------------------------------------------------------------------
	
	gen empstat1=. 
	replace empstat1=0 if Status==4 | Status==3
	replace empstat1=1 if Status==1
	replace empstat1=2 if Status==2

	gen empstat2=.
	replace empstat2=0 if Status==4
	replace empstat2=1 if Status==1
	replace empstat2=2 if Status==2 | Status==3

		label var empstat1 "Employment status, official"
	label var empstat2 "Employment status, expanded"

*-------------------------------------------------------------------------
						*Hours worked
*-------------------------------------------------------------------------

gen hrsnew=.
replace hrsnew=Q419TOTALHRS   if wave>68 & empstat1==1
replace hrsnew=Q4211TOTALHRS  if wave>68 & Q419TOTALHRS==. & Q4211TOTALHRS!=. & empstat1==1  //Hours worked on first job
replace hrsnew=Q4212TOTALHRS  if wave>68 & Q419TOTALHRS==. & Q4212TOTALHRS!=. & empstat1==1  //Hours worked on second job 
replace hrsnew=Q4213TOTALHRS  if wave>68 & Q419TOTALHRS==. & Q4213TOTALHRS!=. & empstat1==1  //Hours worked on all other jobs
		
*----------------------------------------------------------------------	
					* Marital status 
*------------------------------------------------------------------------

	gen marstat=1 if Q16MARITALSTATUS>=1 & Q16MARITALSTATUS<=2
	replace marstat=2 if Q16MARITALSTATUS==3
	replace marstat=3 if Q16MARITALSTATUS==4
	replace marstat=4 if Q16MARITALSTATUS==5
	
*------------------------------------------------------------------------
					*Occupation
*-------------------------------------------------------------------------
 tab Occup
recode Occup (1=1 "Managers") (2= 2 "Professionals") (3 = 3 "Technicians") (4=4 "Clerks") ///
(5= 5 "Services") (6 = 6 "Skilled Agric") (7=7 "Craft & Trade")(8= 8 "Operators")(9=9 "Elementary") (10=10 "Domestic Work") (11=. ), gen(occup) 

label values occup occup

*-------------------------------------------------------------------------
							*Sector
*-------------------------------------------------------------------------
 tab Indus
recode Indus (1=1 "Agriculture")(2= 2 "Mining")(3 = 3 "Manufacturing") (4=4 "Utilities") ///
(5= 5 "Construction")(6 = 6 "Trade")(7=7 "Transport")(8= 8 "Finance")(9=9 "Services") (10=10 "Domestic Work") (11=. ), gen(indussector) 

label values indussector indussector

*-------------------------------------------------------------------------
*union satatus PALMS jobunion=0,1=yes,2=no,3=dont,9=unspeci
								  /*
. tab Q412BMEMUNION

   Trade union |
    membership |      Freq.     Percent        Cum.
---------------+-----------------------------------
        1. Yes |     25,537       32.19       32.19
         2. No |     51,680       65.15       97.34
3. Do not know |      2,113        2.66      100.00
---------------+-----------------------------------
         Total |     79,330      100.00
*/
*-------------------------------------------------------------------------
tab Q412BMEMUNION
generate union=.
replace union=1 if Q412BMEMUNION==1
replace union=0 if Q412BMEMUNION==2
label define UNION 1 "Union Member" 0 "Not Member" 
label values union UNION
label variable union "Union member - dummy"

saveold "$PALMS\qlfsq3q42019.dta", replace


*-------------------------------------------------------------------------
* PALMS
*-------------------------------------------------------------------------
use "$PALMS\palmsv3.3-stata11.dta", clear
*------------------------------------------------------------------------

destring uqnr, replace

*------------------------------------------------------------------------
						*Population group
*-------------------------------------------------------------------------

recode popgroup (1=1 "African/Black") (2= 2 "Coloured") (3 = 3 "Indian/Asian") (4=4 "White") (5=. ) ///
, gen(race) 

label values race race

*-------------------------------------------------------------------------
*Occupation
*-------------------------------------------------------------------------
 tab jobocccode
recode jobocccode (1=1 "Managers") (2= 2 "Professionals") (3 = 3 "Technicians") (4=4 "Clerks") ///
(5= 5 "Services") (6 = 6 "Skilled Agric") (7=7 "Craft & Trade")(8= 8 "Operators")(9=9 "Elementary") (10=10 "Domestic Work") (11 99=. ), gen(occup) 

label values occup occup

*------------------------------------------------------------------------
*Sector
*------------------------------------------------------------------------
 tab jobindcode
recode jobindcode (1=1 "Agriculture")(2= 2 "Mining")(3 = 3 "Manufacturing") (4=4 "Utilities") ///
(5= 5 "Construction")(6 = 6 "Trade")(7=7 "Transport")(8= 8 "Finance")(9=9 "Services") (10=10 "Domestic Work") (11 99=. ), gen(indussector) 

label values indussector indussector

*-------------------------------------------------------------------------
tab jobunion
generate union=.
replace union=1 if jobunion==1
replace union=0 if jobunion==2
label define UNION 1 "Union Member" 0 "Not Member" 
label values union UNION
label variable union "Union member - dummy"
tab union 

*-------------------------------------------------------------------------
*PUBLIC SECTOR 
*-------------------------------------------------------------------------

  	ren publicemp2 public

*-------------------------------------------------------------------------
* Append
*-------------------------------------------------------------------------

append using "$PALMS\qlfsq3q42019.dta"

*-------------------------------------------------------------------------
						*Hours worked
*-------------------------------------------------------------------------
replace hrslstwk=hrsnew if wave>68 &empstat1==1 
*-----------------------------------------------------------------------------


gen hrcat=. 
replace hrcat=0 if hrslstwk==0 & empstat1==1
replace hrcat=1 if (hrslstwk >0 & hrslstwk <35) & empstat1==1 & hrslstwk~=.
replace hrcat=2 if (hrslstwk>=35 & hrslstwk<.) & empstat1==1 & hrslstwk~=. 

		lab define hrcat 0 "Zero hours" 1 "Part-time" 2 "Full-time"   
		lab val hrcat hrcat


*-----------------------------------------------------------------------------
           *Part-time
*-----------------------------------------------------------------------------
		gen part=.
		replace part=1 if hrcat==1
		replace part=0 if hrcat==2
		lab define part 1 "Part-time" 0 "Full-time"  
		lab val part part

*Women still more likely to be in part-time work
*Women lost jobs in part-time work while men switched to part-time work
*Both men and women in full-time work declined, men more than WOmen-men switched to part-time women dropped off

*-----------------------------------------------------------------------------
                                 *LOCATION 
*-----------------------------------------------------------------------------
gen urban=.
replace urban=1 if urbrur==1 & wave<15
replace urban=0 if urbrur==2 & wave<15
replace urban=1 if (urbrur2==1 |urbrur2==2) & (wave>22&wave<51)
replace urban=0 if (urbrur2==4 |urbrur2==5) & (wave>22&wave<51)
replace urban=1 if (urbrur3==1) & (wave>50 & wave<69)
replace urban=0 if (urbrur3>1 & urbrur3!=.) & (wave>50 & wave<69)
replace urban=1 if Geo_type_code==1 & wave>68
replace urban=0 if (Geo_type_code==2|Geo_type_code==3) & wave>68
label define urban 1"urban" 0"rural" 
label values urban urban
label variable urban "Geo-location"

*-----------------------------------------------------------------------------
           *Gender dummy
*-----------------------------------------------------------------------------

recode gender (1=1 "Male") (2=0 "Female"), gen (male)
label values male male

recode gender (1=0 "Male") (2=1 "Female"), gen (female)
label values female female


*-----------------------------------------------------------------------------
           *Employment Status
*-----------------------------------------------------------------------------

gen byte NEA=empstat1==0 if empstat1~=.
gen byte employed=empstat1==1 if empstat1~=.
gen byte unemployed=empstat1==2 if empstat1~=.
gen byte LFP_strict=employed+unemployed

gen byte NEA_broad=empstat2==0 if empstat2~=.
gen byte unemp_broad=empstat2==2 if empstat2~=.
gen byte LFP_broad=employed+unemp_broad

gen disc=0
replace disc=1 if NEA==1 & empstat2>0
replace disc=0 if empstat2==1

*-----------------------------------------------------------------------------
                                 *Population group
*-----------------------------------------------------------------------------

tab race, gen(race_d)

rename race_d1 African
rename race_d2 Coloured
rename race_d3 Indian
rename race_d4 White

*-----------------------------------------------------------------------------
                                       *marital Status
*-----------------------------------------------------------------------------

gen married=.
replace married=1 if marstat==1 
replace married=0 if marstat>=2 & marstat<=4
label define married 1"married" 0"not_married" 
label values married married

*-----------------------------------------------------------------------------
                                 *Occupation
*-----------------------------------------------------------------------------
tab occup, gen(occup1_d)
rename occup1_d1 Managers_occup
rename occup1_d2 Profess_occup
rename occup1_d3 Tech_occup
rename occup1_d4 Clerks_occup
rename occup1_d5 Services_occup
rename occup1_d6 Agric_occup
rename occup1_d7 Craft_occup
rename occup1_d8 Operators_occup
rename occup1_d9 Elemen_occup
rename occup1_d10 dom_occup

*-----------------------------------------------------------------------------
                                 *Sector
*-----------------------------------------------------------------------------

tab indussector, gen(sector1_id)
rename sector1_id1 sec_agric
rename sector1_id2 sec_mining
rename sector1_id3 sec_manuf
rename sector1_id4 sec_utilit
rename sector1_id5 sec_const
rename sector1_id6 sec_trade
rename sector1_id7 sec_trans
rename sector1_id8 sec_finance
rename sector1_id9 sec_servic
rename sector1_id10 sec_dw

*-----------------------------------------------------------------------------
                                 *Education* Code from siyawebsite 
*-----------------------------------------------------------------------------
recode educhigh0 (0=1 "No Schooling") (0/10=2 "Less than Grade 9") (11/13 15 16 18 19 =3 "Grade 9-11") ///
(14 17 20 =4 "Grade 12")  ///
(21=16 "Dipl/cert (no matric)") (22=17 "Dipl/cert (with matric)")(23/25=18 "Degree") ///
(26=.), gen (educ0)

recode educhigh1 (0=1 "No Schooling") (1/9=2 "Less than Grade 9") (10/12=3 "Grade 9-11") ///
(13=4 "Grade 12") (14=5 "N/NCV (NQF2)")  ///
(15=6 "N/NCV (NQF3)") (16=7 "N/NCV (NQF4)") (17=16 "Dipl/cert (no matric)") (18=17 "Dipl/cert (with matric)")(19=18 "Degree") ///
(20=15 "Post-graduate Degree") ///
(21/99=.), gen (educ1)

recode educhigh2 (0=1 "No Schooling") (1/9=2 "Less than Grade 9") (10/12=3 "Grade 9-11") ///
(13=4 "Grade 12") (14=5 "N/NCV (NQF2)")  ///
(15=6 "N/NCV (NQF3)") (16=7 "N/NCV (NQF4)") (17=8 "Certificate (no Grade 12)") ///
(18=9 "Diploma (no Grade 12)") (19=11 "Certificate (with Grade 12)") ///
(20=12 "Diploma (with Grade 12)") (21=14 "Bachelor Degree") ///
(22/24=15 "Post-graduate Degree") ///
(25/99=.), gen (educ2)

recode educhigh3 (98=1 "No Schooling") (0/8=2 "Less than Grade 9") (9/11=3 "Grade 9-11") ///
(12=4 "Grade 12") (13=5 "N/NCV (NQF2)")  ///
(14=6 "N/NCV (NQF3)") (15=7 "N/NCV (NQF4)") (19=8 "Certificate (no Grade 12)") ///
(20=9 "Diploma (no Grade 12)") (16/18=10 "N/NCV (NQF5)") (21=11 "Certificate (with Grade 12)") ///
(22=12 "Diploma (with Grade 12)") (23/24=13 "Higher Diploma") (25=14 "Bachelor Degree") ///
(26/28=15 "Post-graduate Degree") ///
(29/30=.), gen (educ3)

recode educhigh4 (98=1 "No Schooling") (0/8=2 "Less than Grade 9") (9/11=3 "Grade 9-11") ///
(12/13=4 "Grade 12") (14=5 "N/NCV (NQF2)")  ///
(15=6 "N/NCV (NQF3)") (16=7 "N/NCV (NQF4)") (20=8 "Certificate (no Grade 12)") ///
(21=9 "Diploma (no Grade 12)") (17/19=10 "N/NCV (NQF5)") (22=11 "Certificate (with Grade 12)") ///
(23=12 "Diploma (with Grade 12)") (24/25=13 "Higher Diploma") (26=14 "Bachelor Degree") ///
(27/29=15 "Post-graduate Degree") ///
(30/31=.), gen (educ4)

gen educ=.
forvalues x=0/4{
replace educ=educ`x' if educ==.
}

label var educ "Education qual (NQF)"

recode educ  (1/3=1 "Less than gr12") (4=2 "Grade 12")      ///
(5/11=3 "Other tertiary")                 /// *change the label
(12/15=4 "Graduates") , gen(educ_NQF) 

label values educ_NQF educ_NQF

tab educ_NQF, gen(educ_d)
rename educ_d1  lessgr12
rename educ_d2  gr12
rename educ_d3  cert
rename educ_d4  dip_degree


*age
tab age
gen agecat = 1 if age>14 & age<35
replace agecat = 2 if age>34 & age<50
replace agecat = 3 if age>49 & age<65
label define agecat 1 "15-34" 2 "35-49" 3 "50-64"
label values agecat agecat
label variable agecat "Age category"

tab agecat


label define wave1 0 "PSLSD 1993" 1 "OHS 1994"  2 "OHS 1995"  3 "OHS 1996" 4 "OHS1997"      ///
 5 "OHS 1998" 6 "OHS 1999" 7 "LFS 00:1" 8 "LFS 00:2" 9 "LFS 01:1" 10 "LFS 01:2"            ///
 11 "LFS 02:1" 12 "LFS 02:2" 13 "LFS 03:1" 14 "LFS 03:2" 15 "LFS 04:1" 16 "LFS 04:2"      ///
 17 "LFS 05:1" 18 "LFS 05:2" 19 "LFS 06:1" 20 "LFS 06:2" 21 "LFS 07:1" 22 "LFS 07:2"     ///
 23 "QLFS 2008:1" 24 "QLFS 2008:2"  25 "QLFS 2008:3"  26 "QLFS 2008:4"          ///
 27 "QLFS 2009:1" 28 "QLFS 2009:2"  29 "QLFS 2009:3"  30 "QLFS 2009:4"          ///
 31 "QLFS 2010:1" 32 "QLFS 2010:2"  33 "QLFS 2010:3"  34 "QLFS 2010:4"          ///
 35 "QLFS 2011:1" 36 "QLFS 2011:2"  37 "QLFS 2011:3"  38 "QLFS 2011:4"          ///
 39 "QLFS 2012:1" 40 "QLFS 2012:2"  41 "QLFS 2012:3"  42 "QLFS 2012:4"          ///
 43 "QLFS 2013:1" 44 "QLFS 2013:2"  45 "QLFS 2013:3"  46 "QLFS 2013:4"          ///
 47 "QLFS 2014:1" 48 "QLFS 2014:2"  49 "QLFS 2014:3"  50 "QLFS 2014:4"          ///
 51 "QLFS 2015:1" 52 "QLFS 2015:2"  53 "QLFS 2015:3"  54 "QLFS 2015:4"          ///
 55 "QLFS 2016:1" 56 "QLFS 2016:2"  57 "QLFS 2016:3"  58 "QLFS 2016:4"          ///
 59 "QLFS 2017:1" 60 "QLFS 2017:2"  61 "QLFS 2017:3"  62 "QLFS 2017:4"          ///
 63 "QLFS 2018:1" 64 "QLFS 2018:2"  65 "QLFS 2018:3"  66 "QLFS 2018:4"          ///
 67 "QLFS 2019:1" 68 "QLFS 2019:2"  69 "QLFS 2019:3"  70 "QLFS 2019:4"  , replace 

lab values wave wave1

save "$PALMS\PALMS_q3q4qlfs2019.dta", replace




