*-------------------------------------------------------------------------------------*
* Cleaning palms  dataset
*-------------------------------------------------------------------------------------*	
cls 

clear all

cap log close

log using cleaningpalms.log, text replace

*** Setting Global variable for ease of folder navigation

global data "$master\Data"
global temp "$data\temp"
gl PALMS "$data\palms"
gl RESULTS "$master\output"

set more off

use "$PALMS\PALMS_q3q4qlfs2019.dta", clear

replace occupation2=occupation if wave>68

*-------------------------------------------------------------------------------------*	
*keep 2012-2019

keep if wave>38 & wave<71

*cleaning some variables
*-------------------------------------------------------------------------------------*	
							**Age**

cap drop agecat

gen age2=age*age

cap drop agecat
	recode age (15/24=1 "15-24") (25/34=2 "25-34") (35/44=3 "35-44") (45/54=4 "45-54") (55/65=5 "55-65"), gen (agecat)
label values agecat agecat


*-------------------------------------------------------------------------------------*	
							**Education**
*-------------------------------------------------------------------------------------*	

cap drop educ0 educ1 educ2 educ3 educ4 educ_d5 educ_d6 educ_d7 educ educ_NQF lessgr12 gr12 cert dip_degree 
*----------------------------------------------------------------------------------
* QLFSs (2008:1-2012:2)	
*----------------------------------------------------------------------------------
					
recode educhigh2 (0=1 "No Schooling") (1/9=2 "Less than Grade 9") (10/12=3 "Grade 9-11") ///
(13=4 "Grade 12") (14=5 "N/NCV (NQF2)")  ///
(15=6 "N/NCV (NQF3)") (16=7 "N/NCV (NQF4)") (17=8 "Certificate (no Grade 12)") ///
(18=9 "Diploma (no Grade 12)") (19=11 "Certificate (with Grade 12)") ///
(20=12 "Diploma (with Grade 12)") (21=14 "Bachelor Degree") ///
(22/24=15 "Post-graduate Degree") ///
(25/99=.), gen (educ1)

*----------------------------------------------------------------------------------
* QLFSs (2012:3-2016:2)	
*----------------------------------------------------------------------------------
					
recode educhigh3 (98=1 "No Schooling") (0/8=2 "Less than Grade 9") (9/11=3 "Grade 9-11") ///
(12=4 "Grade 12") (13=5 "N/NCV (NQF2)")  ///
(14=6 "N/NCV (NQF3)") (15=7 "N/NCV (NQF4)") (19=8 "Certificate (no Grade 12)") ///
(20=9 "Diploma (no Grade 12)") (16/18=10 "N/NCV (NQF5)") (21=11 "Certificate (with Grade 12)") ///
(22=12 "Diploma (with Grade 12)") (23/24=13 "Higher Diploma") (25=14 "Bachelor Degree") ///
(26/28=15 "Post-graduate Degree") ///
(29/30=.), gen (educ2)

*----------------------------------------------------------------------------------
* QLFSs (2016:3-)		
*----------------------------------------------------------------------------------
				
recode educhigh4 (98=1 "No Schooling") (0/8=2 "Less than Grade 9") (9/11=3 "Grade 9-11") ///
(12/13=4 "Grade 12") (14=5 "N/NCV (NQF2)")  ///
(15=6 "N/NCV (NQF3)") (16=7 "N/NCV (NQF4)") (20=8 "Certificate (no Grade 12)") ///
(21=9 "Diploma (no Grade 12)") (17/19=10 "N/NCV (NQF5)") (22=11 "Certificate (with Grade 12)") ///
(23=12 "Diploma (with Grade 12)") (24/25=13 "Higher Diploma") (26=14 "Bachelor Degree") ///
(27/29=15 "Post-graduate Degree") ///
(30/31=.), gen (educ3)

gen educ=.

forvalues x=1/3{
replace educ=educ`x' if educ==.
}

label var educ "Education qual (NQF)"

recode educ  (1/3=1 "Less than gr12") (4=2 "Grade 12")      ///
(5/11=3 "Other tertiary") (12/15=4 "Graduates") , gen(educ_NQF) 

label values educ_NQF educ_NQF

tab educ_NQF, gen(educ_d)
rename educ_d1  lessgr12
rename educ_d2  gr12
rename educ_d3  cert
rename educ_d4  dip_degree

*-------------------------------------------------------------------------------------*	
							**province dummy**
*-------------------------------------------------------------------------------------*	

tab province, gen(prov_d)
rename prov_d1 wc
rename prov_d2 ec
rename prov_d3 nc
rename prov_d4 fs
rename prov_d5 kzn
rename prov_d6 nw
rename prov_d7 gt
rename prov_d8 mpl
rename prov_d9 limp
*-------------------------------------------------------------------------------------*	
                                   *Hours*
*-------------------------------------------------------------------------------------*	
								   
gen hours=hrslstwk if hrslstwk>0	
gen loghours=log(hours)
*-------------------------------------------------------------------------------------*	
                                   *earnings
*-------------------------------------------------------------------------------------*	

gen logw=log(realearnings)
gen h_wage=realearnings/(hours*4.333)
gen loghw1=log(realearnings/(hours*4.333))        //4.33 Average weeks per month

*-------------------------------------------------------------------------------------*	
                             *sector of employment
*-------------------------------------------------------------------------------------*	
recode indussector (1=1 "agric")(2= 2 "mining")(3 = 3 "manuf") (4=4 "utilities") ///
(5= 5 "construct")(6 = 6 "trade")(7=7 "transport")(8= 8 "finance")(9/10=9 "services"), gen(Indus1) 

lab define Indus9 1 "Agriculture" 2 "Mining" 3 "Manufacturing" 4 "Utilities" 5 "Construction" ///
6 "Trade" 7 "Transport" 8 "Finance" 9 "Services CSP" 

lab val Indus1 Indus9

****sector of employment
tab Indus1, gen(Indus1_id)
rename Indus1_id1 Indus_agric
rename Indus1_id2 Indus_mining
rename Indus1_id3 Indus_manuf
rename Indus1_id4 Indus_utilit
rename Indus1_id5 Indus_const
rename Indus1_id6 Indus_trade
rename Indus1_id7 Indus_trans
rename Indus1_id8 Indus_finance
rename Indus1_id9 Indus_servic


*-------------------------------------------------------------------------------------*	
                             *Occupation/Main Job
*-------------------------------------------------------------------------------------*	

recode occup (1=1 "managers") (2= 2 "profess") (3 = 3 "tech") (4=4 "clerks") ///
(5= 5 "service") (6 = 6 "agric") (7=7 "craft")(8= 8 "operators")(9/10=9 "element"), gen(occup1) 

lab define OCCUP9 1 "Managers" 2 "Professionals" 3 "Technicians" 4 "Clerks" 5 "Services" ///
6 "Skilled Agri" 7 "Craft & Trade" 8 "Operators" 9 "Elementary" 
lab val occup1 OCCUP9

*****main job
tab occup1, gen(occup1_d)
rename occup1_d1 occ_managers
rename occup1_d2 occ_profess
rename occup1_d3 occ_tech
rename occup1_d4 occ_clerks
rename occup1_d5 occ_services
rename occup1_d6 occ_agric
rename occup1_d7 occ_craft
rename occup1_d8 occ_operators
rename occup1_d9 occ_elemen

*-------------------------------------------------------------------------------
			*3 digit occupation code
*-------------------------------------------------------------------------------

tostring occupation2, gen(occuptemp)
gen occ3=substr(occuptemp,1,3)
destring occ3, gen (occup3digit)
drop if occup3digit==999
drop occ3 occuptemp

label define occup3digit 111	"Legislators and senior government officials"   /// 
112	"Senior government officials"	/// 
113	"Traditional chiefs and heads of villages"	/// 
114	"Senior officials of special-interest organisations"	/// 
121	"Directors and chief executives"	/// 
122	"Production and operations managers"	/// 
123	"Other specialist managers"	///
129 "Corporate managers not elsewhere classified"	/// 
131	"Managers of small enterprises" 	///
139  "General managers not elsewhere classified"	///
211	"Physicists, chemists and related professionals"	/// 
212	"Mathematicians, statisticians and related professionals"	/// 
213	"Computing professionals"	/// 
214	"Architects, engineers and related professionals"	/// 
215 "Physical sciences technologists" ///
219 "Physical, mathematical and engineering science professionals not elsewhere classified" ///
221	"Life science professionals" 	/// 
222	"Health professionals (except nursing)"	/// 
223	"Nursing and midwifery professionals" 	/// 
231	"College, university and higher education teaching professionals"	/// 
232	"Secondary education teaching professionals"	/// 
233	"Primary and pre-primary education teaching professionals" 	/// 
234	"Special education teaching professionals"	/// 
235	"Other teaching professionals"	/// 
241	"Business professionals"	/// 
242	"Legal professionals"	/// 
243	"Archivists, librarians and related information professionals"	/// 
244	"Social science and related professionals"	/// 
245	"Writers and creative or performing artists" 	/// 
246	"Religious professionals"	///
249  "Other professionals not elsewhere classified"   ///
311	"Physical and engineering science technicians"	///  
312	"Computer associate professionals" 	/// 
313	"Optical and electronic equipment operators"	/// 
314	"Ship and aircraft controllers and technicians"	/// 
315	"Safety and quality inspectors" 	/// 
321	"Life science technicians and related associate professional" 	/// 
322	"Health associate professionals (except nursing)"	/// 
323	"Nursing and midwifery associate professionals" 	/// 
324	"Traditional medicine practitioners and faith healers"	/// 
331	"Primary education teaching associate professionals"	/// 
332	"Pre-primary education teaching associate professionals"	/// 
333	"Special education teaching associate professionals"	/// 
334	"Other teaching associate professionals"	///
339  "Teaching associate professionals not elsewhere classified " ///
341	"Finance and sales associate professionals" 	/// 
342	"Business services agents and trade brokers" 	/// 
343	"Administrative associate professionals"	/// 
344	"Customs, tax and related government associate professionals"	///  
345	"Police inspectors and detectives"	/// 
346	"Social work associate professionals"	/// 
347	"Artistic, entertainment and sports associate professionals"	/// 			 
348	"Religious associate professionals"	/// 
349 "Other associate professionals not elsewhere classified" ///
411	"Secretaries and keyboard-operating clerks"	/// 
412	"Numerical clerks" 	/// 
413	"Material-recording and transport clerks"	/// 
414	"Library, mail and related clerk"	/// 
419	"Other office clerks"	/// 
421	"Cashiers, tellers and related clerks"	///  
422	"Client information clerks"	///
429  "Customer services clerks not elsewhere classified" ///
511	"Travel attendants and related workers" 	/// 
512	"Housekeeping and restaurant services workers" 	/// 
513	"Personal care and related workers"	/// 
514	"Other personal services workers"	/// 
515	"Astrologers, fortune-tellers and related workers"	/// 
516	"Protective services workers" 	/// 
521	"Fashion and other models"	/// 
522	"Shop salespersons and demonstrators"	/// 
523	"Stall and market salespersons"	/// 
611	"Market gardeners and crop growers"	/// 
612	"Animal producers and related workers"	/// 
613	"Market-oriented crop and animal producers"	/// 
614	"Forestry and related workes"	/// 
615	"Fishery workers, hunters and trappers"	/// 
621	"Subsistence agricultural and fishery workers"	/// 
711	"Miners, shotfirers, stone cutters and carvers"	/// 
712	"Building frame and related trades workers"	/// 
713	"Building finishers and related trades workers"	/// 
714	"Painters, building structure cleaners and related trades workers"	/// 
719 "Extraction and Building trades workers not elsewhere classified"   ///
721	"Metal moulders, welders, sheet-metal workers, structural-metal preparers, and related trades workers"	///  
722	"Blacksmiths, tool-makers and related trades workers" 	/// 
723	"Machinery mechanics and fitters" 	/// 
724	"Electrical and electronic equipment mechanics and fitters"	/// 
729 "Metal, machinery and related trades workers not elsewhere classified "   ///
731	"Precision workers in metal and related materials" 	/// 
732	"Potters, glass-makers and related trades workers" 	/// 
733	"Handicraft workers in wood, textile, leather and related materials"	/// 
734	"Craft printing and related trades workers"	/// 
741	"Food processing and related trades workers"	/// 
742	"Wood treaters, cabinet-makers and related trades workers" 	/// 
743	"Textile, garment and related trades worke"	/// 
744	"Pelt, leather and shoemaking trades workers"	/// 
749 "Other crafts and related trade workers not elsewhere classified"  ///
811	"Mining and mineral-processing-plant operators"		/// 
812	"Metal-processing plant operators"	/// 
813	"Glass, ceramics and related plant operators" 	/// 
814	"Wood-processing- and papermaking-plant operators" 	/// 
815	"Chemical-processing-plant operators" 	/// 
816	"Power-production and related plant operators" 	/// 
817	"Industrial robot operators"	/// 
821	"Metal- and mineral-products machine operators"		/// 
822	"Chemical-products machine operators"	/// 
823	"Rubber- and plastic-products machine operators"	/// 
824	"Wood-products machine operators"	/// 
825	"Printing-, binding- and paper-products machine operators"	/// 
826	"Textile-, fur- and leather-products machine operators"	/// 
827	"Food and related products machine operators" 	/// 
828	"Assemblers" 	/// 
829	"Other machine operators and assemblers"	/// 
831	"Locomotive engine drivers and related workers"	/// 
832	"Motor vehicle drivers"	/// 
833	"Agricultural and other mobile plant operators" 	/// 
834	"Ships' deck crews and related workers"	/// 
911	"Street vendors and related workers" 	/// 
912	"Shoe cleaning and other street services elementary occupations"	/// 
913	"Domestic and related helpers, cleaners and launderers" 	/// 
914	"Building caretakers, window and related cleaners"	/// 
915	"Messengers, porters, doorkeepers and related workers" /// 
916	"Garbage collectors and related labourers" ///
919  "Elementary sales and services occupations not elsewhere classified" ///
921	"Agricultural, fishery and related labourers"	/// 
931	"Mining and construction labourers"	/// 
932	"Manufacturing labourers" 	/// 
933	"Transport labourers and freight handlers"	/// 
011	"Armed forces"

lab val occup3digit  occup3digit
label var  occup3digit "Three digit occupation code"


*-------------------------------------------------------------------------------
			*2 digit occupation code
*-------------------------------------------------------------------------------

tostring occupation2, gen(occuptemp)
gen occ2=substr(occuptemp,1,2)
destring occ2, gen (occup2digit)
drop occ2 occuptemp

label define occup2digit 11	"Legislators and senior officials"   ///
	12	"Corporate managers"  ///
	13	"Managers of small enterprises"  ///
	21	"Physical, mathematical and engineering science professionals"   /// 
	22	"Life science and health professionals"   ///
	23	"Teaching professionals"    /// 
	24	"Other professionals"    ///
	31	"Physical and engineering science associate professionals"  /// 
	32	"Life science and health associate professionals"    ///
	33	"Teaching associate professionals"    /// 
	34	"Other associate professionals"    /// 
	41	"Office clerks"    ///
	42	"Customer services clerk"    ///
	51	"Personal and protective services worker"    ///
	52	"Models, salespersons and demonstrators"    /// 
	61	"Skilled agricultural and fishery workers"    /// 
	62	"Subsistence agricultural and fishery workers"    ///
	71	"Extraction and building trades workers"    /// 
	72	"Metal, machinery and related trades workers"    /// 
	73	"Precision, handicraft, craft printing and related trades workers"    ///
	74	"Other craft and related trades workers"    /// 
	81	"Stationary plant and related operators"    /// 
	82	"Machine operators and assemblers"    /// 
	83	"Drivers and mobile plant operators"    ///
	91	"Sales and services elementary occupations"    /// 
	92	"Agricultural, fishery and related labourers"    /// 
	93	"Labourers in mining, construction, manufacturing and transport"    
	
label values occup2digit occup2digit

*-------------------------------------------------------------------------
			*3 digit industry code
*-------------------------------------------------------------------------

tostring industry2, gen(industemp)
gen indus2=substr(industemp,1,2)
destring indus2, gen (indus2digit)
drop indus2 industemp

lab define indus2digit 10	" Private households with employed persons "	///
11	"	Agriculture, hunting and related services	"	///
12	"	Forestry, logging and related services	"	///
13	"	Fishing, operation of fish hatcheries and fish farms "	///
20	"	Exterritorial organisations and Representatives of foreign governments	"	///
21	"	Mining of coal and lignite	"	///
22	"	Extraction of crude petroleum and natural gas; service activities incidental to oil and gas extraction, excluding surveying	"	///
23	"	Mining of gold and uranium ore	"	///
24	"	Mining of metal ores, except gold and uranium	"	///
25	"	Other mining and quarrying	"	///
29	"	Service activities incidental to mining of minerals	"	///
30	"	Manufacture of food products, beverages and tobacco products	"	///
31	"	Manufacture of textiles, clothing and leather goods	"	///
32	"	Manufacture of wood and of products of wood and cork, except furniture; manufacture of articles of straw and plaiting materials; manufacture of paper and paper products; publishing, printing and reproduction of recorded media	"	///
33	"	Manufacture of coke, refined petroleum products and nuclear fuel; manufacture of chemicals and chemical products; manufacture of rubber and plastic products	"	///
34	"	Manufacture of other non-metallic mineral products	"	///
35	"	Manufacture of basic metals, fabricated metal products, machinery and equipment and of office, accounting and computing machinery	"	///
36	"	Manufacture of electrical machinery and apparatus n.e.c.	"	///
37	"	Manufacture of radio, television and communication equipment and apparatus and of medical, precision and optical instruments, watches and clocks	"	///
38	"	Manufacture of transport equipment	"	///
39	"	Manufacture of furniture; manufacturing n.e.c.; recycling	"	///
41	"	Electricity, gas, steam and hot water supply	"	///
42	"	Collection, purification and distribution of water	"	///
50	"	Construction	"	///
61	"	Wholesale and commission trade, except of motor vehicles and motor cycles	"	///
62	"	Retail trade, except of motor vehicles and motor cycles; repair of personal and household goods	"	///
63	"	Sale, maintenance and repair of motor vehicles and motor cycles; retail trade in automotive fuel	"	///
64	"	Hotels and restaurants	"	///
71	"	Land transport; transport via pipelines	"	///
72	"	Water transport	"	///
73	"	Air transport	"	///
74	"	Supporting and auxiliary transport activities; activities of travel agencies	"	///
75	"	Post and telecommunication	"	///
81	"	Financial intermediation, except insurance and pension funding	"	///
82	"	Insurance and pension funding, except compulsory social security	"	///
83	"	Activities auxiliary to financial intermediation	"	///
84	"	Real estate activities	"	///
85	"	Renting of machinery and equipment, without operator and of personal and household goods	"	///
86	"	Computer and related activities	"	///
87	"	Research and development	"	///
88	"	Other business activities	"	///
91	"	Public administration and defence activities	"	///
92	"	Education	"	///
93	"	Health and social work	"	///
94	"	Other community, social and personal service activities	"	///
95	"	Activities of membership organisations n.e.c.	"	///
96	"	Recreational, cultural and sporting activities	"	///
99	"	Other service activities	"	

lab val indus2digit indus2digit


*-------------------------------------------------------------------------------
			*4 digit Occupation code
*-------------------------------------------------------------------------------

label define occupation2 1110 "Legislators"  	///
1120 "Senior government officials" 	///
1130 "Traditional chiefs and heads of villages"	///
1141 "Senior officials of political-party organisations"	///
1142 "Senior officials of employers', workers' and other economic-interest organisations"	///
1143 "Senior officials of humanitarian and other special-interest organisations"	///
1210 "Directors and chief executives"	///
1211 "Rectors or principals of universities or colleges" ///
1221 "Production and operations department managers in agriculture, hunting, forestry and fishing"	///
1222 "Production and operations department managers in manufacturing"	///
1223 "Production and operations department managers in construction"	///
1224 "Production and operations department managers in wholesale and retail trade"	///
1225 "Production and operations department managers in restaurants and hotels"	///
1226 "Production and operations department managers in transport, storage and communications"	///
1227 "Production and operations department managers in business services"	///
1228 "Production and operations department managers in personal care, cleaning and related services" 	///
1229 "Production and operations department managers not elsewhere classified"	///
1231 "Finance and administration department managers"	///
1232 "Personnel and industrial relations department managers"	///
1233 "Sales and marketing department managers"	///
1234 "Advertising and public relations department managers"		///
1235 "Supply and distribution department managers"	///
1236 "Computing services department managers"	///
1237 "Research and development department managers"	  ///
1239 "Other department managers not elsewhere classified"	///
1290 "Corporate managers not elsewhere classified"	///
1311 "General managers in agriculture, hunting, forestry and fishing"	///
1312 "General managers in manufacturing"		///
1313 "General managers in construction"		///
1314 "General managers in wholesale and retail trade"	///
1315 "General managers of restaurants and hotels"	///
1316 "General managers in transport, storage and communications"	///
1317 "General managers of business services"	///
1318 "General managers in personal care, cleaning and related services"		///
1319 "General managers not elsewhere classified"	///
1390 "General managers not elsewhere classified"	///
2111 "Physicists and astronomers"	///
2112 "Meteorologists"	///
2113 "Chemists"	 ///
2114 "Geologists and geophysicists"	 ///
2121 "Mathematicians and related professionals"	  ///
2122 "Statisticians"	///
2131 "Computer systems designers and analysts"	///
2132 "Computer programmers"	  ///
2139 "Computing professionals not elsewhere classified"	  ///
2141 "Architects, town and traffic planners"	///
2142 "Civil engineers"	  ///
2143 "Electrical engineers"	  ///
2144 "Electronics and telecommunications engineers"	  ///
2145 "Mechanical engineers"	  ///
2146 "Chemical engineers"	  ///
2147 "Mining engineers, metallurgists and related professionals"	///
2148 "Cartographers and surveyors"	  ///
2149 "Architects, engineers and related professionals not elsewhere classified"	   ///
2159	"Physical sciences technologists" ///
2190	"Physical, mathematical and engineering science professionals not elsewhere classified" ///
2210 		"Scientist"		///
2211 "Biologists, botanists, zoologists and related professionals"	///
2212 "Pharmacologists, pathologists and related professionals"	 ///
2213 "Agronomists and related professionals"	 ///
2221 "Medical doctors"	  ///
2222 "Dentists"	    ///
2223 "Veterinarians"	///
2224 "Pharmacists"	   ///
2229 "Health professionals (except nursing) not elsewhere classified"	///
2230	"Nursing and midwifery professionals"		///
2310	"College, university and higher education teaching professionals"	///
2320	"Secondary education teaching professionals"	///
2331	"Primary education teaching professionals"	///
2332	"Pre-primary education teaching professionals"	///
2340	"Special education teaching professionals"	///
2351	"Education methods specialists"	///
2352	"School inspectors"	///
2359	"Other teaching professionals not elsewhere classified"	///
2411	"Accountants"	///
2412	"Personnel and careers professionals"	///
2419	"Business professionals not elsewhere classified"	///
2421	"Lawyers" ///
2422	"Judges" ///
2429	"Legal professionals not elsewhere classified" ///
2431	"Archivists and curators" ///
2432	"Librarians and related information professionals" ///
2441	"Economists" ///
2442	"Sociologists, anthropologists and related professionals" ///
2443	"Philosophers, historians and political scientists" ///
2444	"Philologists, translators and interpreters" ///
2445	"Psychologists"  ///
2446	"Social work professionals" ///
2451	"Authors, journalists and other writers" ///
2452	"Sculptors, painters and related artists"  ///
2453	"Composers, musicians and singers"  ///
2454	"Choreographers and dancers"  ///
2455	"Film, stage and related actors and directors"       ///
2460	"Religious professionals"   ///
2490	"Other professionals not elsewhere classified"   ///
3111	"Chemical and physical science technicians"   ///
3112	"Civil engineering technicians"	///
3113	"Electrical engineering technicians" ///
3114	"Electronics and telecommunications engineering technicians" ///
3115	"Mechanical engineering technicians" ///
3116	"Chemical engineering technicians" ///
3117	"Mining and metallurgical technicians" ///
3118	"Draughtspersons" ///
3119	"Physical and engineering science technicians not elsewhere classified" ///
3121	"Computer assistants" ///
3122	"Computer equipment operators" ///
3123	"Industrial robot controllers" ///
3131	"Photographers and image and sound recording equipment operators" ///
3132	"Broadcasting and telecommunications equipment operators" ///
3133	"Medical equipment operators" ///
3141	"Ships' engineers" ///
3142	"Ships' deck officers and pilots" ///
3143	"Aircraft pilots and related associate professionals" ///
3144	"Air traffic controllers" ///
3145	"Air traffic safety technicians" ///
3151	"Building and fire inspectors" ///
3152	"Safety, health and quality inspectors" ///
3211	"Life science technicians" ///
3212	"Agronomy and forestry technicians" ///
3213	"Farming and forestry advisers" ///
3220	"Optometrist' assistants" ///
3221	"Medical assistants" ///
3222	"Sanitarians" ///
3223	"Dieticians and nutritionists" ///
3224	"Optometrists and opticians" ///
3225	"Dental assistants" ///
3226	"Physiotherapists and related associate professionals" ///
3227	"Veterinary assistants" ///
3228	"Pharmaceutical assistants" ///
3229	"Modern health associate professionals (except nursing) not elsewhere classified" ///
3231	"Nursing associate professionals" ///
3232	"Midwifery associate professionals" ///
3241	"Traditional medicine practitioners" ///
3242	"Faith healers" ///
3310	"Primary education teaching associate professionals" ///
3320	"Pre-primary education teaching associate professionals" ///
3330	"Special education teaching associate professionals" ///
3340	"Other teaching associate professionals" ///
3391	"Teaching associate professionals not elsewhere classified " ///
3411	"Securities and finance dealers and brokers" ///
3412	"Insurance representatives" ///
3413	"Estate agents" ///
3414	"Travel consultants and organisers" ///
3415	"Technical and commercial sales representatives" ///
3416	"Buyers" ///
3417	"Appraisers, valuers and auctioneers" ///
3419	"Finance and sales associate professionals not elsewhere classified" ///
3421	"Trade brokers" ///
3422	"Clearing and forwarding agents" ///
3423	"Employment agents and labour contractors" ///
3429	"Business services agents and trade brokers not elsewhere classified" ///
3431	"Administrative secretaries and related associate professionals" ///
3432	"Legal and related business associate professionals" ///
3433	"Bookkeepers" ///
3434	"Statistical, mathematical and related associate professionals" ///
3439	"Administrative associate professionals not elsewhere classified" ///
3441	"Customs and border inspectors" ///
3442	"Government tax and excise officials" ///
3443	"Government social benefits officials" ///
3444	"Government licensing officials" ///
3449	"Customs, tax and related government associate professionals not elsewhere classified" ///
3450	"Police inspectors and detectives" ///
3460	"Social work associate professionals" ///
3461	"Reseacher, social" ///
3471	"Decorators and commercial designers" ///
3472	"Radio, television and other announcers" ///
3473	"Street, night-club and related musicians, singers and dancers" ///
3474	"Clowns, magicians, acrobats and related associate professionals" ///
3475	"Athletes, sportspersons and related associate professionals" ///
3479	"Art, entertainment and sport associate professionals not elsewhere classified" ///
3480	"Religious associate professionals" ///
3490	"Other associate professionals not elsewhere classified" ///
4111	"Stenographers and typists" ///
4112	"Word-processor and related operators" ///
4113	"Data entry operators" ///
4114	"Calculating-machine operators" ///
4115	"Secretaries" ///
4121	"Accounting and bookkeeping clerks" ///
4122	"Statistical and finance clerks" ///
4131	"Stock clerks" ///
4132	"Production clerks" ///
4133	"Transport clerks" ///
4141	"Library and filing clerks" ///
4142	"Mail carriers and sorting clerks" ///
4143	"Coding, proof-reading and related clerks" ///
4144	"Scribes and related workers" ///
4190	"Other office clerks" ///
4211	"Cashiers and ticket clerks" ///
4212	"Tellers and other counter clerks" ///
4213	"Bookmakers and croupiers" ///
4214	"Pawnbrokers and money-lenders" ///
4215	"Debt-collectors and related workers" ///
4221	"Travel agency and related clerks" ///
4222	"Receptionists and information clerks" ///
4223	"Telephone switchboard operators" ///
4290	"Customer services clerks not elsewhere classified" ///
5111	"Travel attendants and travel stewards" ///
5112	"Transport conductors" ///
5113	"Travel guides" ///
5121	"Housekeepers and related workers" ///
5122	"Cooks" ///
5123	"Waiters, waitresses and bartenders" ///
5124	"Operators, tavern, shebeen" ///
5131	"Child-care workers" ///
5132	"Institution-based personal care workers" ///
5133	"Home-based personal care workers" ///
5139	"Personal care and related workers not elsewhere classified" ///
5141	"Hairdressers, barbers, beauticians and related workers" ///
5142	"Companions and valets" ///
5143	"Undertakers and embalmers" ///
5149	"Other personal services workers not elsewhere classified" ///
5151	"Astrologers and related workers" ///
5152	"Fortune-tellers, palmists and related workers" ///
5161	"Fire-fighters" ///
5162	"Police officers" ///
5163	"Prison guards" ///
5164	"Armed forces " ///
5169	"Protective services workers not elsewhere classified" ///
5210	"Fashion and other models" ///
5220	"Shop salespersons and demonstrators" ///
5230	"Stall and market salespersons" ///
5231	"Owner, spaza shop" ///
6111 	"Field crop and vegetable growers"	 ///
6112 	"Tree and shrub crop growers"	 ///
6113 	"Gardeners, horticultural and nursery growers"	 ///
6114 	"Mixed-crop growers"	///
6121 	"Dairy and livestock producers"	///
6122	"Poultry producers" ///
6123	"Apiarists and sericulturists" ///
6124 	"Mixed-animal producers"	 ///
6129	"Market-oriented animal producers and related workers not elsewhere classified" ///
6130	"Market-oriented crop and animal producers" ///
6141	"Forestry workers and loggers" ///
6142	"Charcoal burners and related workers" ///
6151	"Aquatic-life cultivation workers" /// 
6152	"Inland and coastal waters fishery workers" ///
6153	"Deep-sea fishery workers"  ///
6154	"Hunters and trappers"  ///
6210	"Subsistence agricultural and fishery workers"  ///
6211	"Subsistence farmers"  ///
7111	"Miners and quarry workers"  ///
7112	"Shotfirers and blasters"  ///
7113	"Stone splitters, cutters and carvers"   ///
7114	"Diamond drivers"   ///
7121	"Builders, traditional materials"   ///
7122	"Bricklayers and stonemasons"   ///
7123	"Concrete placers, concrete finishers and related workers"   ///
7124	"Carpenters and joiners"   ///
7129	"Building frame and related trades workers not elsewhere classified"  ///
7131	"Roofers"  ///
7132	"Floor layers and tile setters"  ///
7133	"Plasterers" ///
7134	"Insulation workers" ///
7135	"Glaziers"   ///
7136	"Plumbers and pipe fitters"  ///
7137	"Building and related electricians"  ///
7141	"Painters and related workers"  ///
7142	"Varnishers and related painters"   ///
7143	"Building structure cleaners"   ///
7190	"Extraction and Building trades workers not elsewhere classified"   ///
7211	"Metal moulders and coremakers"   ///
7212	"Welders and flamecutters"  ///
7213	"Sheet-metal workers"   ///
7214	"Structural-metal preparers and erectors"   ///
7215	"Riggers and cable splicers"   ///
7216	"Underwater workers"   ///
7221	"Blacksmiths, hammer-smiths and forging-press workers"    ///
7222	"Tool-makers and related workers"   ///
7223	"Machine-tool setters and setter-operators"   ///
7224	"Metal wheel-grinders, polishers and tool sharpeners"   ///
7231	"Motor vehicle mechanics and fitters"   ///
7232	"Aircraft engine mechanics and fitters"   ///
7233	"Agricultural- or industrial-machinery mechanics and fitters"  ///
7241	"Electrical mechanics and fitters"  ///
7242	"Electronics fitters"  ///
7243	"Electronics mechanics and servicers"   ///
7244	"Telegraph and telephone installers and servicers"  ///
7245	"Electrical line installers, repairers and cable jointers"   ///
7290	"Metal, machinery and related trades workers not elsewhere classified "   ///
7311	"Precision-instrument makers and repairers"  ///
7312	"Musical instrument makers and tuners"  ///
7313	"Jewellery and precious-metal workers" ///
7321	"Abrasive wheel formers, potters and related workers"  ///
7322	"Glass-makers, cutters, grinders and finishers"   ///
7323	"Glass engravers and etchers"   ///
7324	"Glass, ceramics and related decorative painters"   ///
7331	"Handicraft workers in wood and related materials"   ///
7332	"Handicraft workers in textile, leather and related materials"   ///
7341	"Compositors, typesetters and related workers"   ///
7342	"Stereotypers and electrotypers"   ///
7343	"Printing engravers and etchers"   ///
7344	"Photographic and related workers"    ///
7345	"Bookbinders and related workers"    ///
7346	"Silk-screen, block and textile printers"   ///
7411	"Butchers, fishmongers and related food preparers"  ///
7412	"Bakers, pastry-cooks and confectionery makers"  ///
7413	"Dairy-products makers" ///
7414	"Fruit, vegetable and related preservers" ///
7415	"Food and beverage tasters and graders"  ///
7416	"Tobacco preparers and tobacco products makers"  ///
7421	"Wood treaters"  ///
7422	"Cabinet-makers and related workers"  ///
7423	"Woodworking-machine setters and setter-operators"  ///
7424	"Basketry weavers, brush makers and related workers"  ///
7431	"Fibre preparers"	///
7432	"Weavers, knitters and related workers"  ///
7433	"Tailors, dressmakers and hatters"  ///
7434	"Furriers and related workers"  ///
7435	"Textile, leather and related pattern-makers and cutters"  ///
7436	"Sewers, embroiderers and related workers"  ///
7437	"Upholsterers and related workers"  ///
7441	"Pelt dressers, tanners and fellmongers"  ///
7442	"Shoe-makers and related workers"  ///
7490	"Other crafts and related trade workers not elsewhere classified"  ///
8111	"Mining-plant operators"   ///
8112	"Mineral-ore- and stone-processing-plant operators"   ///
8113	"Well drillers and borers and related workers"  ///
8121	"Ore and metal furnace operators"  ///
8122	"Metal melters, casters and rolling-mill operators"  ///
8123	"Metal-heat-treating-plant operators"  ///
8124	"Metal drawers and extruders"  ///
8131	"Glass and ceramics kiln and related machine operators"  ///
8139	"Glass, ceramics and related plant operators not elsewhere classified"   ///
8141	"Wood-processing-plant operators"  ///
8142	"Paper-pulp plant operators"  ///
8143	"Papermaking-plant operators"  ///
8151	"Crushing-, grinding- and chemical-mixing machinery operators"  ///
8152	"Chemical-heat-treating-plant operators"  ///
8153	"Chemical-filtering- and separating-equipment operators"  ///
8154	"Chemical-still and reactor operators (except petroleum and natural gas)"  ///
8155	"Petroleum- and natural-gas-refining-plant operators"  ///
8159	"Chemical-processing-plant operators not elsewhere classified"  ///
8161	"Power-production plant operators"  ///
8162	"Steam-engine and boiler operators"  ///
8163	"Incinerator, water-treatment and related plant operators"  ///
8171	"Automated-assembly-line operators"  ///
8172	"Industrial-robot operators"  ///
8211	"Machine-tool operators"  ///
8212	"Cement and other mineral products machine operators"  ///
8221	"Pharmaceutical- and toiletry-products machine operators"  ///
8222	"Ammunition- and explosive-products machine operators"  ///
8223	"Metal finishing-, plating- and coating-machine operators"  ///
8224	"Photographic-products machine operators"  ///
8229	"Chemical-products machine operators not elsewhere classified"  ///
8231	"Rubber-products machine operators"  ///
8232	"Plastic-products machine operators"  ///
8240	"Wood-products machine operators"  ///
8251	"Printing-machine operators"  ///
8252	"Bookbinding-machine operators"  ///
8253	"Paper-products machine operators"  ///
8261	"Fibre-preparing-, spinning- and winding-machine operators"  ///
8262	"Weaving- and knitting-machine operators"  ///
8263	"Sewing-machine operators"  ///
8264	"Bleaching-, dyeing- and cleaning-machine operators"  ///
8265	"Fur- and leather-preparing-machine operators"  ///
8266	"Shoemaking- and related machine operators"  ///
8269	"Textile-, fur- and leather-products machine operators not elsewhere classified"  ///
8271	"Meat- and fish-processing-machine operators"  ///
8272	"Dairy-products machine operators"  ///
8273	"Grain- and spice-milling-machine operators"  ///
8274	"Baked-goods, cereal and chocolate-products machine operators"  ///
8275	"Fruit-, vegetable- and nut-processing-machine operators"  ///
8276	"Sugar production machine operators"  ///
8277	"Tea-, coffee-, and cocoa-processing-machine operators"  ///
8278	"Brewers-, wine and other beverage machine operators"  ///
8279	"Tobacco production machine operators"  ///
8281	"Mechanical-machinery assemblers"  ///
8282	"Electrical-equipment assemblers"  ///
8283	"Electronic-equipment assemblers"   ///
8284	"Metal-, rubber- and plastic-products assemblers"	///
8285	"Wood and related products assemblers"	///
8286	"Paperboard, textile and related products assemblers"	///
8290	"Other machine operators and assemblers"	///
8311	"Locomotive-engine drivers"	///
8312	"Railway brakers, signallers and shunters"	///
8320	"Driver, taxi"	///
8321	"Motor-cycle drivers"	///
8322	"Car, taxi and van drivers"	///
8323	"Bus and tram drivers"	///
8324	"Heavy truck and lorry drivers"	///
8331	"Motorised farm and forestry plant operators"	///
8332	"Earth-moving- and related plant operators"	///
8333	"Crane, hoist and related plant operators"	///
8334	"Lifting-truck operators"	///
8340	"Ships' deck crews and related workers"	///
9111	"Street food vendors"	///
9112	"Street vendors, non-food products"	///
9113	"Door-to-door and telephone salespersons"	///
9120	"Shoe cleaning and other street services elementary occupations"	///
9131	"Domestic helpers and cleaners"	///
9132	"Helpers and cleaners in offices, hotels and other establishments" ///
9133	"Hand-launderers and pressers" ///
9141	"Building caretakers" ///
9142	"Vehicle, window and related cleaners" ///
9151	"Messengers, package and luggage porters and deliverers" ///
9152	"Doorkeepers, watchpersons and related workers" ///
9153	"Vending-machine money collectors, meter readers and related workers" ///
9161	"Garbage collectors" ///
9162	"Sweepers and related labourers" ///
9190	"Elementary sales and services occupations not elsewhere classified" ///
9211	"Farm-hands and labourers" ///
9212	"Forestry labourers" ///
9213	"Fishery, hunting and trapping labourers" ///
9311	"Mining and quarrying labourers" ///
9312	"Construction and maintenance labourers: roads, dams and similar constructions" ///
9313	"Building construction labourers" ///
9321	"Assembling labourers" ///
9322	"Hand packers and other manufacturing labourers" ///
9331	"Hand or pedal vehicle drivers" ///
9332	"Drivers of animal-drawn vehicles and machinery" ///
9333	"Freight handlers" ///
0110	"Armed forces"

lab val occupation2  occupation2 


*-------------------------------------------------------------------------------------*	
gen newweight32=ceweight1/32

g bracketweight24= bracketweight/24

keep if employed==1
keep if age>=15&age<=65

save "$PALMS\palms4waves.dta", replace
*-------------------------------------------------------------------------------------*	
log close

exit
